<template>
    <header :class="['main-navbar fixed-top py-3', isScrolled ? 'scrolled shadow-sm bg-white' : 'bg-transparent']">
        <div class="container d-flex align-items-center justify-content-between">
            <!-- Logo -->
            <div class="d-flex align-items-center gap-2">
                <img src="/images/logo.png" alt="Logo" height="32" />
                <span class="fw-bold fs-5 text-dark">BKK SMEKSAKER</span>
            </div>

            <!-- Toggle (Mobile) -->
            <button
                class="navbar-toggler d-md-none border-0"
                type="button"
                @click="toggleMenu"
            >
                <span class="navbar-toggler-icon"></span>
            </button>

            <!-- Menu -->
            <nav :class="['nav-links d-md-flex gap-4', showMenu ? 'd-flex flex-column position-absolute top-100 start-0 w-100 bg-white p-3' : 'd-none']">
                <LoginDropdown/>
            </nav>
        </div>
    </header>
</template>

<script setup>
import { ref, onMounted, onBeforeUnmount } from 'vue'
import LoginDropdown from "@/Components/Landing/LoginDropdown.vue";

const isScrolled = ref(false)
const showMenu = ref(false)

const handleScroll = () => {
    isScrolled.value = window.scrollY > 50
}

const toggleMenu = () => {
    showMenu.value = !showMenu.value
}

onMounted(() => {
    window.addEventListener('scroll', handleScroll)
})

onBeforeUnmount(() => {
    window.removeEventListener('scroll', handleScroll)
})
</script>

<style scoped>
.main-navbar {
    transition: background-color 0.3s ease, box-shadow 0.3s ease;
    z-index: 1050;
}

.nav-link {
    color: #212529;
    text-decoration: none;
}
.nav-link:hover {
    color: #4b4bff;
}

.btn-primary {
    background-color: #3f3fff;
    border: none;
    border-radius: 4px;
}
.btn-primary:hover {
    background-color: #2d2df5;
}

.navbar-toggler-icon {
    background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='%23212529' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%2821, 21, 21, 0.5%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e");
}
</style>
